==> 0.0.2.tar.gz: lib/components/senior_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

abstract class SeniorSwitchTheme {
  static Color getSwitchActiveColor({ required Brightness theme }) {
    return SeniorColors.primaryColor;
  }

  static Color getSwitchTrackColor({ required Brightness theme }) {
    return SeniorColors.secondaryColor600;
  }

  static Color getSwitchTextColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorSwitch extends StatelessWidget {
  final String title;
  final bool value;
  final Function(bool? value) onChanged;
  final bool disabled;

  SeniorSwitch({
    required Key key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Row(
      children: [
        Container(
          margin: EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          child: CupertinoSwitch(
            value: this.value,
            onChanged: !this.disabled ? this.onChanged : null,
            activeColor: SeniorSwitchTheme.getSwitchActiveColor(theme: theme),
            trackColor: SeniorSwitchTheme.getSwitchTrackColor(theme: theme),
          ),
        ),
        Flexible(
          child: Text(
            this.title,
            style: SeniorTypography.getTextStyle(
              token: SeniorTypographyTokens.text,
              color: SeniorSwitchTheme.getSwitchTextColor(theme: theme, isDisabled: this.disabled),
            ),
          ),
        )
      ],
    );
  }
}

==> 0.2.0.tar.gz: lib/components/senior_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorSwitchTheme {
  SeniorSwitchTheme._();

  static Color getSwitchActiveColor({ required Brightness theme }) {
    return SeniorColors.primaryColor;
  }

  static Color getSwitchTrackColor({ required Brightness theme }) {
    return SeniorColors.secondaryColor600;
  }

  static Color getSwitchTextColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorSwitch extends StatelessWidget {
  final String title;
  final bool value;
  final Function(bool?) onChanged;
  final bool disabled;

  const SeniorSwitch({
    Key? key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Row(
      children: [
        Container(
          margin: EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          child: CupertinoSwitch(
            value: this.value,
            onChanged: !this.disabled ? this.onChanged : null,
            activeColor: SeniorSwitchTheme.getSwitchActiveColor(theme: theme),
            trackColor: SeniorSwitchTheme.getSwitchTrackColor(theme: theme),
          ),
        ),
        Flexible(
          child: Text(
            this.title,
            style: SeniorTypography.getTextStyle(
              token: SeniorTypographyTokens.text,
              color: SeniorSwitchTheme.getSwitchTextColor(theme: theme, isDisabled: this.disabled),
            ),
          ),
        )
      ],
    );
  }
}
